==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ItemLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ItemLegendDescription } from "./ItemLegendDescription";
/**
 * @hidden
 */
export let ItemLegendDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemLegendDescriptionMetadata extends Base {
        static e(a) {
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        }
        static b(a) {
            if (ItemLegendDescriptionMetadata.a == null) {
                ItemLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemLegendDescriptionMetadata.c(ItemLegendDescriptionMetadata.a);
            }
            if (a.g(ItemLegendDescriptionMetadata.a)) {
                return;
            }
            a.s(ItemLegendDescriptionMetadata.a);
        }
        static c(a) {
            LegendBaseDescriptionMetadata.c(a);
            a.item("Orientation", "ExportedType:string:LegendOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("TextColor", "String");
            a.item("TextStyle", "String");
            ItemLegendDescriptionMetadata.e(a);
        }
        static d(a) {
            ItemLegendDescriptionMetadata.b(a);
            a.u("ItemLegend", () => new ItemLegendDescription());
            a.t("ItemLegend", ItemLegendDescriptionMetadata.a);
        }
    }
    ItemLegendDescriptionMetadata.$t = /*@__PURE__*/ markType(ItemLegendDescriptionMetadata, 'ItemLegendDescriptionMetadata');
    ItemLegendDescriptionMetadata.a = null;
    return ItemLegendDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ItemLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ItemLegendDescription } from "./ItemLegendDescription";
/**
 * @hidden
 */
export let ItemLegendDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemLegendDescriptionMetadata extends Base {
        static e(a) {
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        }
        static b(a) {
            if (ItemLegendDescriptionMetadata.a == null) {
                ItemLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemLegendDescriptionMetadata.c(ItemLegendDescriptionMetadata.a);
            }
            if (a.j(ItemLegendDescriptionMetadata.a)) {
                return;
            }
            a.y(ItemLegendDescriptionMetadata.a);
        }
        static c(a) {
            LegendBaseDescriptionMetadata.c(a);
            a.item("Orientation", "ExportedType:string:LegendOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("TextColor", "String");
            a.item("TextStyle", "String");
            ItemLegendDescriptionMetadata.e(a);
        }
        static d(a) {
            ItemLegendDescriptionMetadata.b(a);
            a.aa("ItemLegend", () => new ItemLegendDescription());
            a.z("ItemLegend", ItemLegendDescriptionMetadata.a);
        }
    }
    ItemLegendDescriptionMetadata.$t = /*@__PURE__*/ markType(ItemLegendDescriptionMetadata, 'ItemLegendDescriptionMetadata');
    ItemLegendDescriptionMetadata.a = null;
    return ItemLegendDescriptionMetadata;
})();
